@@ -157,6 +157,12 @@ class Container(PolymorphicModel, ShowFieldContent, Publishable, Slugged,
                            containerbox__slug=containerbox)
         return obj.filter(container=self.id)
 
+    def custom_fields(self):
+        import json
+        if not self.json:
+            return
+        return json.loads(self.json)
+
 
 class ContainerImage(models.Model):
     container = models.ForeignKey(
@@ -302,6 +308,9 @@ class ContainerBoxContainers(models.Model):
             return u"{0}".format(self.containerbox.slug)
 
     def clean(self):
+        if not self.container and not self.url:
+            raise ValidationError(_(u'Please select a Container or insert a '
+                                    u'URL!'))
 
         if self.container and not self.container.published:
             raise ValidationError(_(u'Article not published!'))
