@@ -2,7 +2,7 @@
 
 from django import template
 from django.conf import settings
-from opps.core.utils import get_app_model
+from opps.core.models import Config
 
 register = template.Library()
 
@@ -10,7 +10,7 @@ CONFIG_DICT = getattr(settings, 'OPPS_GET_CONFIG_DICT', None)
 
 
 @register.simple_tag
-def get_config(appname, key, **kwargs):
+def get_config(app_label, key, **kwargs):
     """
     {% load config %}
     {% get_config 'polls' 'key_slug' %}
@@ -30,21 +30,28 @@ def get_config(appname, key, **kwargs):
         except:
             pass
 
-    model = get_app_model(appname, "Config")
-    return model and model.get_value(key, **kwargs)
+    if app_label in ['none', 'null', 'None']:
+        try:
+            del kwargs['app_label']
+        except:
+            pass
+
+    return Config.get_value(key, **kwargs)
 
 
 @register.simple_tag
-def get_configs(appname, key_group, **kwargs):
+def get_configs(app_label, key_group, **kwargs):
     """
     {% load config %}
     {% get_configs 'polls' 'key_group_slug' %}
     {% get_configs 'infographics' 'key_group_slug' %}
     {% get_configs 'promos' 'key_group_slug' %}
-
-    Also works
-    {% get_configs 'opps.polls' 'key_group_slug' %}
     """
 
-    model = get_app_model(appname, "Config")
-    return model and model.get_values(key_group, **kwargs)
+    if app_label in ['none', 'null', 'None']:
+        try:
+            del kwargs['app_label']
+        except:
+            pass
+
+    return Config.get_values(key_group, **kwargs)
