@@ -2,8 +2,7 @@
 from django.db import models
 from django.utils.translation import ugettext_lazy as _
 
-from opps.core.models import BaseConfig
-from opps.articles.signals import shorturl_generate
+from opps.containers.signals import shorturl_generate
 from opps.articles.models import Article
 
 
@@ -13,8 +12,8 @@ class FlatPage(Article):
     order = models.IntegerField(_(u"Order"), default=0)
 
     class Meta:
-        verbose_name = _(u'Flat page')
-        verbose_name_plural = _(u'Flat pages')
+        verbose_name = _(u'Flatpage')
+        verbose_name_plural = _(u'Flatpages')
 
     def get_absolute_url(self):
         return u"/page/{0}".format(self.slug)
@@ -25,11 +24,4 @@ class FlatPage(Article):
     get_http_absolute_url.short_description = 'URL'
 
 
-class FlatPageConfig(BaseConfig):
-    """
-    Default implementation
-    """
-    pass
-
-
 models.signals.post_save.connect(shorturl_generate, sender=FlatPage)
